ftceffect_player library

Classes

FAnimPlayListener
FEffectResource
FMixInfo
FMixInfoMsg
FMixItem
FMixItemMsg
FResourceFetcher
FResourceMsg
FTCEffectAnimInfo
FTCEffectAnimInfoMsg
FTCEffectAnimView
FTCEffectAnimViewApi
FTCEffectAnimViewFlutterEvent
FTCEffectAnimViewState
FTCEffectConfig
FTCEffectConfigMsg
Pigeon original component, used to generate native communication code for messages. The generation command is as follows. When using the generation command, the two import statements above need to be implemented or commented out.
FTCEffectPlayerConstant
FTCEffectText
FTCEffectTextMsg
FTCEffectViewController
FTCMediaXBase
FTCMediaXBaseApi
FTCMediaXBaseFlutterEvent
LogLevel
LogUtils
log print tools

Extensions

StringExt on String

Functions

wrapResponse({Object? result, PlatformException? error, bool empty = false}) List<Object?>

Typedefs

FEffectViewControllerCallback = void Function(FTCEffectViewController controller)
FEmptyFunction = void Function()
FIntParamsFunction = void Function(int code)
FOnPlayEventFunction = void Function(int event, Map params)
FResClickListener = void Function(FEffectResource res)
FResImgResultFetcher = Uint8List Function(FEffectResource res)
FResReleaseListener = void Function(List<FEffectResource> resList)
FResTextResultFetcher = FTCEffectText Function(FEffectResource res)
FTCMediaLicenseListener = void Function(int errCode, String msg)