FEffectResource class

Constructors

FEffectResource()

Properties

bitmapByte Uint8List?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
loadType String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
srcType String?
getter/setter pair
tag String?
getter/setter pair
text String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

copyFromMsg(FResourceMsg msg) FEffectResource