FMixInfoMsg class

Constructors

FMixInfoMsg({List<FMixItemMsg>? textMixItemList, List<FMixItemMsg>? imageMixItemList})

Properties

hashCode int
The hash code for this object.
no setterinherited
imageMixItemList List<FMixItemMsg>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textMixItemList List<FMixItemMsg>?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) FMixInfoMsg