FResourceFetcher class

Constructors

FResourceFetcher({FResImgResultFetcher? imgFetcher, FResTextResultFetcher? textFetcher, FResReleaseListener? releaseListener})

Properties

hashCode int
The hash code for this object.
no setterinherited
imgFetcher FResImgResultFetcher?
getter/setter pair
releaseListener FResReleaseListener?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textFetcher FResTextResultFetcher?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited