FTCEffectAnimInfoMsg class

Constructors

FTCEffectAnimInfoMsg({int? type, int? duration, int? width, int? height, int? encryptLevel, FMixInfoMsg? mixInfo})

Properties

duration int?
getter/setter pair
encryptLevel int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int?
getter/setter pair
mixInfo FMixInfoMsg?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int?
getter/setter pair
width int?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) FTCEffectAnimInfoMsg