FTCEffectAnimViewApi class
Constructors
- FTCEffectAnimViewApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
-
Constructor for FTCEffectAnimViewApi. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pigeonVar_binaryMessenger → BinaryMessenger?
-
final
- pigeonVar_messageChannelSuffix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSdkVersion(
) → Future< String> -
getTCAnimInfo(
) → Future< FTCEffectAnimInfoMsg> -
isPlaying(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDestroy(
) → Future< void> -
pause(
) → Future< void> -
preloadTCAnimInfo(
String playUrl, FTCEffectConfigMsg config) → Future< FTCEffectAnimInfoMsg> -
requestUpdateResource(
) → Future< void> -
resume(
) → Future< void> -
seekProgress(
double progress) → Future< void> -
seekTo(
int milliSec) → Future< void> -
setConfig(
FTCEffectConfigMsg config) → Future< void> -
setDuration(
int durationInMilliSec) → Future< void> -
setLoop(
bool isLoop) → Future< void> -
setLoopCount(
int loopCount) → Future< void> -
setMute(
bool mute) → Future< void> -
setRate(
double rate) → Future< void> -
setRenderRotation(
int rotation) → Future< void> -
setScaleType(
int scaleTypeValue) → Future< void> -
setVideoMode(
int videoModeValue) → Future< void> -
startPlay(
String playUrl) → Future< int> -
stopPlay(
bool clearLastFrame) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>