FTCEffectConfig class

Constructors

FTCEffectConfig()

Properties

animType FAnimType?
getter/setter pair
codecType FCodecType?
getter/setter pair
extendMapParams Map<String, Object>
getter/setter pair
freezeFrame FFreezeFrame?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMsg() FTCEffectConfigMsg
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited