FTCEffectConfigMsg class

Pigeon original component, used to generate native communication code for messages. The generation command is as follows. When using the generation command, the two import statements above need to be implemented or commented out.

Constructors

FTCEffectConfigMsg({int? codecTypeValue, int? freezeFrame, int? animTypeValue, Map<Object?, Object?>? extendMapParams})

Properties

animTypeValue int?
getter/setter pair
codecTypeValue int?
getter/setter pair
extendMapParams Map<Object?, Object?>?
getter/setter pair
freezeFrame int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) FTCEffectConfigMsg