FTCEffectPlayerConstant class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- REPORT_ANIM_INFO → const int
- REPORT_ERROR_TYPE_ADVANCE_MEDIA_PLAYER → const int
- REPORT_ERROR_TYPE_HEVC_NOT_SUPPORT → const int
- REPORT_ERROR_TYPE_INVALID_LICENSE → const int
- REPORT_ERROR_TYPE_INVALID_PARAM → const int
- REPORT_ERROR_TYPE_MC_DECODER → const int
- REPORT_ERROR_TYPE_UNKNOWN_ERROR → const int
- REPORT_INFO_ON_NEED_SURFACE → const int
- REPORT_INFO_ON_PLAY_EVT_CHANGE_RESOLUTION → const int
- REPORT_INFO_ON_PLAY_EVT_LOOP_ONCE_COMPLETE → const int
- REPORT_INFO_ON_PLAY_EVT_PLAY_END → const int
- REPORT_INFO_ON_PLAY_EVT_RCV_FIRST_I_FRAME → const int
- REPORT_INFO_ON_VIDEO_CONFIG_READY → const int
- REPORT_INFO_ON_VIDEO_SIZE_CHANGE → const int