FTCEffectTextMsg class

Constructors

FTCEffectTextMsg({String? text, String? fontStyle, int? color, int? alignment, double? fontSize})

Properties

alignment int?
getter/setter pair
color int?
getter/setter pair
fontSize double?
getter/setter pair
fontStyle String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) FTCEffectTextMsg