FTCMediaXBase class

Inheritance

Properties

curLicenseListener FTCMediaLicenseListener?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mediaXBaseApi FTCMediaXBaseApi
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enableCompatMode(bool enable) Future<void>
设置是否启用兼容模式 当启用时,在特定设备(如 Pixel)上动画 PlatformView 会使用更稳定的渲染方式, 可以避免出现的 fd 泄漏和 GPU crash 问题。 @param enable true 启用兼容模式(默认),false 禁用
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLicenseResult(int errCode, String msg) → void
mediaXBase api end /// mediaXBase event start ///
override
setLicense(String url, String key, FTCMediaLicenseListener listener) Future<void>
mediaXBase api start ///
setLogEnable(bool enable) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FTCMediaXBase
no setter