FTCEffectAnimViewFlutterEvent class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchImage(
FResourceMsg res) → Uint8List? -
fetchText(
FResourceMsg res) → FTCEffectTextMsg? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPlayEnd(
) → void -
onPlayError(
int errCode) → void -
onPlayEvent(
int event, Map< Object?, Object?> param) → void -
onPlayStart(
) → void -
onResClick(
FResourceMsg res) → void -
releaseResource(
List< FResourceMsg> resourceList) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
setUp(
FTCEffectAnimViewFlutterEvent? api, {BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''}) → void
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>