FTCEffectText class
Constructors
Properties
- alignment ↔ int?
-
getter/setter pair
- color ↔ int?
-
getter/setter pair
- fontSize ↔ double?
-
getter/setter pair
- fontStyle ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMsg(
) → FTCEffectTextMsg -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- TEXT_ALIGNMENT_CENTER → const int
- TEXT_ALIGNMENT_LEFT → const int
- TEXT_ALIGNMENT_NONE → const int
- TEXT_ALIGNMENT_RIGHT → const int