FTCMediaXBaseApi class
Constructors
- FTCMediaXBaseApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
-
Constructor for FTCMediaXBaseApi. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pigeonVar_binaryMessenger → BinaryMessenger?
-
final
- pigeonVar_messageChannelSuffix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enableCompatMode(
bool enable) → Future< void> - 设置是否启用兼容模式
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLicense(
String url, String key) → Future< void> -
setLogEnable(
bool enable) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>